@@ -13,7 +13,7 @@ class ServicoAdmin(admin.ModelAdmin):
 
 
 class FilialServicoAdmin(admin.ModelAdmin):
-    list_display = ['produto', 'precolista']
+    list_display = ['cd_filial', 'servico']
 
 
 class FilialHoraFuncionamentoAdmin(admin.ModelAdmin):
