@@ -5,6 +5,12 @@ import core.usr.models
 
 
 class FuncionarioLogin(core.usr.models.Profile):
+    """
+    :Nome da classe/função: FuncionarioLogin
+    :descrição: Classe de login para funcionários
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     funcionario = models.OneToOneField('funcionario.Funcionario', on_delete=models.DO_NOTHING, null=True)
 
     class Meta(core.models.Log.Meta):
@@ -13,6 +19,12 @@ class FuncionarioLogin(core.usr.models.Profile):
 
 
 class Funcionario(core.models.Log, core.models.PessoaLog):
+    """
+    :Nome da classe/função: FuncionarioLogin
+    :descrição: Classe de funcionários e informações pessoais
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     matricula = models.CharField(max_length=200, primary_key=True)
     cargo = models.ForeignKey('funcionario.Cargo', on_delete=models.DO_NOTHING, null=True)
     imagem = models.FileField(upload_to='fotos/funcionarios', default='fotos/sem-foto.png', null=True)
@@ -23,6 +35,12 @@ class Funcionario(core.models.Log, core.models.PessoaLog):
 
 
 class Cargo(core.models.Log):
+    """
+    :Nome da classe/função: FuncionarioLogin
+    :descrição: Classe de cargos de funcionários
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     nome = models.CharField(max_length=200, primary_key=True)
     cargo_pai = models.ForeignKey('self', on_delete=models.DO_NOTHING, null=True)
     nm_descritivo = models.CharField(max_length=500, null=True)
